# Bluemath {**Toolkit**}

Module collection for custom climate data analysis. The main objective of this Python package is to provide a set of statistical tools tailored for climate data analysis, with a focus on statistical classification and prediction.

The package also includes a set of utility functions for processing climate data. To facilitate understanding of how to use these modules, simple demonstration scripts and the necessary data have been added to this repository.

## Main contents

![Sketch](./docs/sketch_tk.png)

Link to the different sections:
- [datamining](./bluemath_tk/datamining/)
- [waves](./bluemath_tk/waves/)
- [predictor](./bluemath_tk/predictor/)
- [TC](./bluemath_tk/tc/)
- [distributions](./bluemath_tk/distributions/)
- [wrappers](./bluemath_tk/wrappers/)
- [risk](./bluemath_tk/risk/)
- [tide](./bluemath_tk/tide/)

## Demos

In this repository, simple demo files showcasing the utilization of the different tools can be found in this [link](./demos). Furthermore, full examples with figures can be found in the [Bluemath - notebooks](./) repository.

## Authors

Codes have been developed through a collaborative effort by members of the GeoOcean group at the University of Cantabria. For inquiries, please contact Fernando Méndez at mendezf@unican.es

## License

This project is licensed under the MIT License. See the [license](LICENSE.txt) file for details

## Project status

- UNDER DEVELOPMENT

# TODOs

- Check whole code in NNs
- Check climate scale data in SamoaTonga
- Add logs to datamining classes.
- Descomentar crontab, que ya funcionan los sh
- Add ERA5 spectra download.
- Add docker, sbatch, et options in wrappers!